@@ -3,6 +3,7 @@ from typing import Dict
 from ts_t1_validator.services.t1 import T1Service
 from ts_t1_validator.validators.abstract_validator import AbstractValidator
 from ts_t1_validator.validators.campaign_post_validator import CampaignPostValidator
+from ts_t1_validator.validators.strategy_post_validator import StrategyPostValidator
 
 
 class T1Validator:
@@ -11,12 +12,14 @@ class T1Validator:
         t1_service = T1Service(t1_creds=t1_creds)
         if validator_type == "campaign":
             self.validator = CampaignPostValidator(t1_service=t1_service)
+        elif validator_type == "strategy":
+            self.validator = StrategyPostValidator(t1_service=t1_service)
         else:
             raise NotImplemented()
 
-    def validate(self, dto: Dict):
+    def validate(self, *args, **kwargs):
         """
         Proxy validate method to proper class
         :return:
         """
-        return self.validator.validate(dto=dto)
+        return self.validator.validate(*args, **kwargs)
