@@ -41,7 +41,7 @@ class ProgrammaticGuaranteedOverridesRule(ValidationRule):
         if self.spend_cap_type != CapTypeEnum.NO_LIMIT:
             raise ValidationException(when_pg_message % "spend_cap_type must be 'no-limit'")
 
-        if self.spend_cap_automatic is not None:
+        if self.spend_cap_automatic is not False:
             raise ValidationException(when_pg_message % "spend_cap_automatic must be 'off'")
 
         if self.spend_cap_amount is not None:
